import{d as m,g as y,W as k,h as _,i as s,G as o,j as d,c as e,o as t,k as n,a as r,q as v,n as c,aH as C,F as g,aN as h,aO as x}from"./index-DHPxdPUs.js";import{u as A}from"./usePageTitle-N_Vwn3MG.js";const T=m({__name:"ArtifactKey",setup(B){const u=y(),i=k("artifactKey"),l=_(u.artifacts.getArtifactCollection,[i]),a=s(()=>l.response),f=s(()=>a.value?`${o.info.artifact}: ${a.value.key}`:o.info.artifact);return A(f),(K,w)=>{const p=d("p-layout-default");return t(),e(p,{class:"artifact"},{header:n(()=>[a.value?(t(),e(c(x),{key:0,artifact:a.value},null,8,["artifact"])):r("",!0)]),default:n(()=>[a.value?(t(),e(c(C),{key:0,artifact:a.value},null,8,["artifact"])):r("",!0),a.value?(t(),v(g,{key:1},[a.value.key?(t(),e(c(h),{key:0,"artifact-key":a.value.key},null,8,["artifact-key"])):r("",!0)],64)):r("",!0)]),_:1})}}});export{T as default};
//# sourceMappingURL=ArtifactKey-DJJCfWhA.js.map
