import{d as o,j as r,c,o as n,k as a,l as e,n as t,aP as _,aQ as f}from"./index-DHPxdPUs.js";import{u as l}from"./usePageTitle-N_Vwn3MG.js";const x=o({__name:"Artifacts",setup(p){return l("Artifacts"),(u,i)=>{const s=r("p-layout-default");return n(),c(s,{class:"artifacts"},{header:a(()=>[e(t(f))]),default:a(()=>[e(t(_))]),_:1})}}});export{x as default};
//# sourceMappingURL=Artifacts-Dl2tK381.js.map
