import{d as l,g as p,j as _,c as m,o as C,k as e,l as o,n,cz as d,cA as h,c7 as c,be as i,J as w}from"./index-DHPxdPUs.js";import{u as y}from"./usePageTitle-N_Vwn3MG.js";const k=l({__name:"NotificationCreate",setup(N){const r=p();async function s(t){try{await r.notifications.createNotification(t),c.push(i.notifications())}catch(a){w("Error creating notification","error"),console.warn(a)}}function u(){c.push(i.notifications())}return y("Create Notification"),(t,a)=>{const f=_("p-layout-default");return C(),m(f,{class:"notification-create"},{header:e(()=>[o(n(h))]),default:e(()=>[o(n(d),{action:"Create",onSubmit:s,onCancel:u})]),_:1})}}});export{k as default};
//# sourceMappingURL=NotificationCreate-DQQcpPeQ.js.map
