import{d,g as i,u as b,W as _,i as o,bF as f,j as v,c as D,a as B,o as C,k as c,l as n,n as s,cs as g,ct as h,be as w}from"./index-DHPxdPUs.js";import{u as x}from"./usePageTitle-N_Vwn3MG.js";const S=d({__name:"BlockView",setup(y){const u=i(),l=b(),t=_("blockDocumentId"),a=o(()=>t.value?[t.value]:null),r=f(u.blockDocuments.getBlockDocument,a),e=o(()=>r.response),m=()=>{l.push(w.blocks())},k=o(()=>e.value?`Block: ${e.value.name}`:"Block");return x(k),(V,I)=>{const p=v("p-layout-default");return e.value?(C(),D(p,{key:0,class:"block-view"},{header:c(()=>[n(s(h),{"block-document":e.value,onDelete:m},null,8,["block-document"])]),default:c(()=>[n(s(g),{"block-document":e.value},null,8,["block-document"])]),_:1})):B("",!0)}}});export{S as default};
//# sourceMappingURL=BlockView-0b6y0NeH.js.map
