import{d as w,g,W as x,u as D,i as l,aI as I,al as O,bt as R,h as S,j as u,c,o as n,k as a,l as T,n as t,a6 as B,a as r,cO as N,cP as m,cQ as P,be as V}from"./index-DHPxdPUs.js";import{u as W}from"./usePageTitle-N_Vwn3MG.js";const Z=w({__name:"ConcurrencyLimit",setup(j){const p=g(),y=x("concurrencyLimitId"),d=D(),v=l(()=>[{label:"Details",hidden:I.xl},{label:"Active Task Runs"}]),s=O("tab","Details"),{tabs:_}=R(v,s),b={interval:3e5},L=S(p.concurrencyLimits.getConcurrencyLimit,[y.value],b),e=l(()=>L.response);function f(){d.push(V.concurrencyLimits())}const C=l(()=>e.value?`Concurrency Limit: ${e.value.tag}`:"Concurrency Limit");return W(C),(A,i)=>{const k=u("p-tabs"),h=u("p-layout-well");return n(),c(h,{class:"concurrencyLimit"},{header:a(()=>[e.value?(n(),c(t(P),{key:0,"concurrency-limit":e.value,onDelete:f},null,8,["concurrency-limit"])):r("",!0)]),well:a(()=>[e.value?(n(),c(t(m),{key:0,alternate:"","concurrency-limit":e.value},null,8,["concurrency-limit"])):r("",!0)]),default:a(()=>[T(k,{selected:t(s),"onUpdate:selected":i[0]||(i[0]=o=>B(s)?s.value=o:null),tabs:t(_)},{details:a(()=>[e.value?(n(),c(t(m),{key:0,"concurrency-limit":e.value},null,8,["concurrency-limit"])):r("",!0)]),"active-task-runs":a(()=>{var o;return[(o=e.value)!=null&&o.activeSlots?(n(),c(t(N),{key:0,"active-slots":e.value.activeSlots},null,8,["active-slots"])):r("",!0)]}),_:1},8,["selected","tabs"])]),_:1})}}});export{Z as default};
//# sourceMappingURL=ConcurrencyLimit-DL4AWTUu.js.map
