import{d,ae as m,g as _,i as o,h as v,G as b,j as h,c as r,o as t,k as c,q as k,a as y,F as C,n,cW as g,cX as x,l as B,cY as D}from"./index-DHPxdPUs.js";import{u as V}from"./usePageTitle-N_Vwn3MG.js";const j=d({__name:"Variables",setup(w){const l=m(),a=()=>{var e;s.value.refresh(),(e=l.value)==null||e.refreshSubscriptions()},u=_(),s=o(()=>v(u.variables.getVariables)),i=o(()=>{var e;return s.value.executed&&((e=s.value.response)==null?void 0:e.length)===0}),p=o(()=>s.value.executed);return V(b.info.variables),(e,F)=>{const f=h("p-layout-default");return t(),r(f,{class:"variables"},{header:c(()=>[B(n(D),{onCreate:a})]),default:c(()=>[p.value?(t(),k(C,{key:0},[i.value?(t(),r(n(g),{key:0,onCreate:a})):(t(),r(n(x),{key:1,ref_key:"table",ref:l,onDelete:a,onUpdate:a},null,512))],64)):y("",!0)]),_:1})}}});export{j as default};
//# sourceMappingURL=Variables-CROOx_Po.js.map
