import{d as f,g as i,h as _,i as o,j as w,c as s,o as t,k as n,q as C,a as k,F as b,n as a,bM as h,bN as y,l as v,bO as x}from"./index-DHPxdPUs.js";import{u as F}from"./usePageTitle-N_Vwn3MG.js";const V=f({__name:"Flows",setup(g){const l=i(),c={interval:3e4},e=_(l.flows.getFlowsCount,[{}],c),r=o(()=>e.response??0),u=o(()=>e.executed&&r.value===0),p=o(()=>e.executed),d=()=>{e.refresh()};return F("Flows"),(N,B)=>{const m=w("p-layout-default");return t(),s(m,{class:"flows"},{header:n(()=>[v(a(x))]),default:n(()=>[p.value?(t(),C(b,{key:0},[u.value?(t(),s(a(h),{key:0})):(t(),s(a(y),{key:1,selectable:"",onDelete:d}))],64)):k("",!0)]),_:1})}}});export{V as default};
//# sourceMappingURL=Flows-mtMsJuqu.js.map
