import{d as v,aR as y,aS as V,g as C,h as x,i,aT as F,j as d,c as _,o as n,k as l,q as m,a as R,l as a,F as S,n as e,aU as U,m as r,aV as B,aW as A,f as N,aX as T,aY as D,B as E,z as P,E as W,aZ as j,ay as q}from"./index-DHPxdPUs.js";import{s as Y}from"./index-B4HswuBc.js";const z={class:"workspace-dashboard__header-actions"},H={class:"workspace-dashboard__subflows-toggle"},I={key:1,class:"workspace-dashboard__grid"},M={class:"workspace-dashboard__side"},G=v({__name:"Dashboard",setup(Q){y(V,{interval:Y(30)});const f=C(),c=x(f.flowRuns.getFlowRunsCount,[{}]),u=i(()=>c.executed),p=i(()=>c.response===0),b=[{text:"Dashboard"}],s=F({range:{type:"span",seconds:-86400},tags:[]}),g=()=>N.map("WorkspaceDashboardFilter",s,"TaskRunsFilter");return(X,o)=>{const k=d("p-toggle"),w=d("p-button"),h=d("p-layout-default");return n(),_(h,{class:"workspace-dashboard"},{header:l(()=>[a(e(P),{crumbs:b,class:"workspace-dashboard__page-heading"},W({_:2},[u.value&&!p.value?{name:"actions",fn:l(()=>[r("div",z,[r("div",H,[a(k,{modelValue:e(s).hideSubflows,"onUpdate:modelValue":o[0]||(o[0]=t=>e(s).hideSubflows=t),append:"Hide subflows"},null,8,["modelValue"])]),a(e(j),{selected:e(s).tags,"onUpdate:selected":o[1]||(o[1]=t=>e(s).tags=t),"empty-message":"All tags"},null,8,["selected"]),a(e(q),{modelValue:e(s).range,"onUpdate:modelValue":o[2]||(o[2]=t=>e(s).range=t),class:"workspace-dashboard__date-select"},null,8,["modelValue"])])]),key:"0"}:void 0]),1024)]),default:l(()=>[u.value?(n(),m(S,{key:0},[p.value?(n(),_(e(U),{key:0})):(n(),m("div",I,[a(e(B),{filter:e(s)},null,8,["filter"]),r("div",M,[a(e(A),{filter:g}),a(e(T),{class:"workspace-dashboard__work-pools",filter:e(s)},null,8,["filter"])])]))],64)):R("",!0),a(e(D),{title:"Ready to scale?",subtitle:"Webhooks, role and object-level security, and serverless push work pools on Prefect Cloud"},{actions:l(()=>[a(w,{to:"https://www.prefect.io/cloud-vs-oss?utm_source=oss&utm_medium=oss&utm_campaign=oss&utm_term=none&utm_content=none",target:"_blank",primary:""},{default:l(()=>o[3]||(o[3]=[E(" Upgrade to Cloud ")])),_:1})]),_:1})]),_:1})}}});export{G as default};
//# sourceMappingURL=Dashboard-D85qaiKC.js.map
