import{d as R,g as h,W as I,h as N,i as p,ae as S,al as V,G as _,aG as $,j as r,c,o as l,k as e,q as D,a as i,l as s,n as t,aH as G,aI as H,aJ as d,B as L,t as U,aK as v,a6 as W,aL as m,aM as j}from"./index-DHPxdPUs.js";import{u as q}from"./usePageTitle-N_Vwn3MG.js";const E={key:0},Z=R({__name:"Artifact",setup(J){const b=h(),k=I("artifactId"),w=N(b.artifacts.getArtifact,[k]),a=p(()=>w.response),n=S(!1),y=[{label:"Artifact"},{label:"Details"},{label:"Raw"}],u=V("tab","Artifact"),C=p(()=>a.value?`${_.info.artifact}: ${a.value.key??$(a.value.type)}`:_.info.artifact);return q(C),(K,o)=>{const g=r("p-divider"),x=r("p-button"),A=r("p-content"),T=r("p-tabs"),B=r("p-layout-well");return l(),c(B,{class:"artifact"},{header:e(()=>[a.value?(l(),c(t(j),{key:0,artifact:a.value},null,8,["artifact"])):i("",!0)]),well:e(()=>[a.value?(l(),c(t(m),{key:0,artifact:a.value,alternate:""},null,8,["artifact"])):i("",!0)]),default:e(()=>[a.value?(l(),D("section",E,[s(t(G),{artifact:a.value},null,8,["artifact"]),s(g),t(H).xl?(l(),c(A,{key:0},{default:e(()=>[s(t(d),{artifact:a.value},null,8,["artifact"]),s(x,{class:"artifact__raw-data-button",small:"",onClick:o[0]||(o[0]=f=>n.value=!n.value)},{default:e(()=>[L(U(n.value?"Hide":"Show")+" raw data ",1)]),_:1}),n.value?(l(),c(t(v),{key:0,artifact:a.value},null,8,["artifact"])):i("",!0)]),_:1})):(l(),c(T,{key:1,selected:t(u),"onUpdate:selected":o[1]||(o[1]=f=>W(u)?u.value=f:null),tabs:y},{artifact:e(()=>[s(t(d),{artifact:a.value},null,8,["artifact"])]),details:e(()=>[s(t(m),{artifact:a.value},null,8,["artifact"])]),raw:e(()=>[s(t(v),{artifact:a.value},null,8,["artifact"])]),_:1},8,["selected"]))])):i("",!0)]),_:1})}}});export{Z as default};
//# sourceMappingURL=Artifact-s4yu9NDg.js.map
