import{i as o,n as a,bw as c}from"./index-DHPxdPUs.js";function u(...t){const r=[...t,"Prefect Server"],n=o(()=>r.map(e=>a(e)).filter(e=>e!==null).join(" • "));c(()=>document.title=n.value)}export{u};
//# sourceMappingURL=usePageTitle-N_Vwn3MG.js.map
