import{d as v,i as h,q as u,o as i,l as e,k as t,F as x,x as C,t as f,n,dy as B,I as w,j as l,c as A,dz as F,a6 as P,dA as p,z as V}from"./index-DHPxdPUs.js";import{u as j}from"./usePageTitle-N_Vwn3MG.js";import{u as q}from"./usePrefectApi-73S4sE5q.js";import"./api-Br1VH0Tb.js";import"./mapper-BEWLxiBI.js";const z={class:"settings-block"},M=v({__name:"SettingsCodeBlock",props:{engineSettings:{}},setup(d){const s=d,o=h(()=>Object.entries(s.engineSettings));return(g,c)=>(i(),u("div",z,[e(n(B),{multiline:""},{default:t(()=>[(i(!0),u(x,null,C(o.value,(a,r)=>(i(),u("div",{key:r,class:"settings-block--code-line"},f(a[0])+": "+f(a[1]),1))),128))]),_:1})]))}}),O=v({__name:"Settings",async setup(d){let s,o;const g=[{text:"Settings"}],c=q(),[a,r]=([s,o]=w(()=>Promise.all([c.admin.getSettings(),c.admin.getVersion()])),s=await s,o(),s);return j("Settings"),(T,m)=>{const S=l("p-key-value"),b=l("p-theme-toggle"),_=l("p-label"),k=l("p-layout-default");return i(),A(k,{class:"settings"},{header:t(()=>[e(n(V),{crumbs:g},{actions:t(()=>[e(S,{class:"settings__version",label:"Version",value:n(r),alternate:""},null,8,["value"])]),_:1})]),default:t(()=>[e(_,{label:"Theme"},{default:t(()=>[e(b)]),_:1}),e(_,{label:"Color Mode",class:"settings__color-mode"},{default:t(()=>[e(n(F),{selected:n(p),"onUpdate:selected":m[0]||(m[0]=y=>P(p)?p.value=y:null)},null,8,["selected"])]),_:1}),e(_,{label:"Server Settings"},{default:t(()=>[e(M,{class:"settings__code-block","engine-settings":n(a)},null,8,["engine-settings"])]),_:1})]),_:1})}}});export{O as default};
//# sourceMappingURL=Settings-Ducm2Yhu.js.map
