import{d as e,c as o,o as a,n as t,dB as n}from"./index-DHPxdPUs.js";import{u as r}from"./usePageTitle-N_Vwn3MG.js";const m=e({__name:"404",setup(s){return r("Page Not Found"),(c,p)=>(a(),o(t(n)))}});export{m as default};
//# sourceMappingURL=404-DAQLWYVo.js.map
