import{d as f,g as C,V as x,W as c,i as r,aC as I,aD as b,I as y,j as D,c as E,a as h,n as e,o as k,k as n,l as s,aE as w,z as F,aF as V}from"./index-DHPxdPUs.js";import{u as g}from"./usePageTitle-N_Vwn3MG.js";const q=f({__name:"Event",async setup(B){let a,o;const l=C(),u=x(),v=c("eventDate"),_=c("eventId"),m=r(()=>I(v.value)),d=b({startDate:m,eventId:[_.value]}),t=([a,o]=y(()=>l.events.getFirstEvent(d.value)),a=await a,o(),a),p=r(()=>[{text:"Event Feed",to:u.events()},{text:t.eventLabel}]);return g(`Event: ${t.eventLabel}`),(L,N)=>{const i=D("p-layout-default");return e(t)?(k(),E(i,{key:0,class:"event"},{header:n(()=>[s(e(F),{crumbs:p.value},{actions:n(()=>[s(e(V),{event:e(t)},null,8,["event"])]),_:1},8,["crumbs"])]),default:n(()=>[s(e(w),{event:e(t)},null,8,["event"])]),_:1})):h("",!0)}}});export{q as default};
//# sourceMappingURL=Event-TAci2mbr.js.map
