import{d as m,g as p,h as d,i as a,j as _,c as s,o as t,k as c,q as k,a as f,F as i,n as o,cf as h,cg as y,l as B,ch as C}from"./index-DHPxdPUs.js";import{u as g}from"./usePageTitle-N_Vwn3MG.js";const E=m({__name:"Blocks",setup(x){const n=p(),e=d(n.blockDocuments.getBlockDocumentsCount),l=a(()=>e.executed&&e.response==0),r=a(()=>e.executed);return g("Blocks"),(D,b)=>{const u=_("p-layout-default");return t(),s(u,{class:"blocks"},{header:c(()=>[B(o(C))]),default:c(()=>[r.value?(t(),k(i,{key:0},[l.value?(t(),s(o(h),{key:0})):(t(),s(o(y),{key:1,onDelete:o(e).refresh},null,8,["onDelete"]))],64)):f("",!0)]),_:1})}}});export{E as default};
//# sourceMappingURL=Blocks-CrWADJQK.js.map
