import{d as g,g as y,h as k,i as s,j as r,c as n,o as a,k as i,l,q as v,a as x,B as N,F as C,n as o,cw as w,cx as B,cy as V}from"./index-DHPxdPUs.js";import{u as b}from"./usePageTitle-N_Vwn3MG.js";const T=g({__name:"Notifications",setup(h){const u=y(),t=k(u.notifications.getNotifications),c=s(()=>t.response??[]),f=s(()=>t.executed&&c.value.length===0),p=s(()=>t.executed);return b("Notifications"),(D,e)=>{const d=r("p-message"),m=r("p-layout-default");return a(),n(m,{class:"notifications"},{header:i(()=>[l(o(V))]),default:i(()=>[l(d,{info:""},{default:i(()=>e[2]||(e[2]=[N(" Notifications are deprecated and will be migrated in the future. Please use Automations. ")])),_:1}),p.value?(a(),v(C,{key:0},[f.value?(a(),n(o(w),{key:0})):(a(),n(o(B),{key:1,notifications:c.value,onDelete:e[0]||(e[0]=_=>o(t).refresh()),onUpdate:e[1]||(e[1]=_=>o(t).refresh())},null,8,["notifications"]))],64)):x("",!0)]),_:1})}}});export{T as default};
//# sourceMappingURL=Notifications-OmNoN9Ng.js.map
